@@ -8,21 +8,21 @@ XUL::Gui is right.
 gui programming has always been hard, be it a simple form, or a complex dynamic interface,
 the learning curve has always been steep, the boilerplate painful, and the design patterns,
 well, they have been quite tedious.
-then came HTML, and with it a clean, clear, and consisise nested programming style, that has,
+then came HTML, and with it a clean, clear, and concise nested programming style, that has,
 for the most part, logical and intuitive functions and styling.  it has taken some time for
-web browsers to support user intefaces on a par with the native gui in most operating systems
+web browsers to support user interfaces on a par with the native gui in most operating systems
 but that time has come.  firefox, available for all major operating systems, provides a rich
 and extensible framework for developing cross platform gui applications.  these applications are
-written in XUL, mozilla's gui development language, the same language that firefox itself is written
-in.  HTML is also fully supported, and can be freely intermixed with XUL.  as powerfull as XUL and
-HTML are, they are fundementally bound to javascript, which if you're anything like me, just isn't
+written in XUL, Mozilla's gui development language, the same language that firefox itself is written
+in.  HTML is also fully supported, and can be freely intermixed with XUL.  as powerful as XUL and
+HTML are, they are fundamentally bound to javascript, which if you're anything like me, just isn't
 a suitable replacement for perl.
 
 XUL::Gui seeks not only to fully integrate all of the features of the XUL and HTML markup languages,
 in both XML and functional forms, but to also proxy every property, attribute and method from
-javascript to perl and back enabling transparent maniputlation of the DOM in pure perl.
+javascript to perl and back enabling transparent manipulation of the DOM in pure perl.
 
-as functional as XUL and the DOM are, they arent always the most convenient, otherwise the various
+as functional as XUL and the DOM are, they aren't always the most convenient, otherwise the various
 javascript frameworks would not exist.  the XUL::Gui proxy aims to smooth some of the DOM's rough
 edges by abstracting away the difference between properties and attributes, and adding plural versions
 of many functions (you can also use any javascript framework with XUL::Gui by simply including it in a
@@ -62,7 +62,7 @@ every XUL and HTML tag is imported into your namespace with the following spelli
 
 the nesting of tags can be arbitrarily deep and complex and functions of course follow all the
 same nesting rules as XML.  however unlike XML, the attributes, properties and children
-of a tag can be distributed in any order, but its probably best for readablity to keep them at
+of a tag can be distributed in any order, but its probably best for readability to keep them at
 the front of the @_ list.  of course all arguments, children most usefully, are processed in order
 
     Hbox(
@@ -94,17 +94,17 @@ attributes, properties and methods
 inside the hashref itself, all UPPERCASE keys are reserved, but feel free to use any
 other keys as you want.  a few useful reserved keys to know are:
 
-    ID      the supplied or autogenerated id
-    TAG     the XUL or HTML tagname
+    ID      the supplied or auto generated id
+    TAG     the XUL or HTML tag name
     A       a hashref containing the creation time attribute and _property settings
-    C       an arrayref containing the creation time children
+    C       an array ref containing the creation time children
     M       a hashref for user defined methods
     W       the parent widget if it exists
 
 all tags are loaded into the exported %ID hash with their specified id or an
-autogenerated one.  all reserved ids match C</^xul_\d+/>
+auto generated one.  all reserved ids match C</^xul_\d+/>
 
-tag objects are accessed as folows:
+tag objects are accessed as follows:
 
     js:     ID.btn = document.createElement('button');
             ID.btn.setAttribute('id', 'btn');
@@ -136,7 +136,7 @@ setting the attribute works better.
     js:     ID.btn._prop = 5;     // a property that starts with _
     perl:   $ID{btn}->__prop = 5;  # only the first _ is shifted off
 
-attributes dont start with underscores so they are safe, in the rare event of an attribute
+attributes don't start with underscores so they are safe, in the rare event of an attribute
 that is not a perl C<\w>, just use the normal C<(get|set)Attribute()> call
 
     js:     ID.btn.callMethod();
@@ -161,7 +161,7 @@ maps to three in javascript (and abstracts away the tedious C<(set|get)Attribute
     print $ID{btn}->method(_);      # forced method, called as ID.btn.someMethod();
                                     # a bit of a kludge, but such a collision is rare
                                     # as nearly all accessor functions are implemented
-                                    # as properties, which in turn usually dont collide
+                                    # as properties, which in turn usually don't collide
                                     # with attributes.  but just in case, the overrides
                                     # are available
 
@@ -178,7 +178,7 @@ appropriate proxy object.
 
 the bidirectional translation between perl and javascript is:
 
-        Javascript      |           Perl
+        JavaScript      |           Perl
     --------------------|-------------------------
         Array           |   ARRAY ref               # not implemented yet
         Object          |   Tag Object
@@ -196,8 +196,8 @@ this is fine for most events, but there are occasions when large changes need to
 that would be too slow to send individually to the client.
 
 if you need to add many elements to the gui, you could write it in javascript with the
-gui('javascript here') call, but that would be tedious, and larry tells us we should be lazy.
-so use the prefered method of generating your objects with the tag subs, and utilize map to factor
+gui('javascript here') call, but that would be tedious, and Larry tells us we should be lazy.
+so use the preferred method of generating your objects with the tag subs, and utilize map to factor
 out some of XML's repetition.  since tag objects are not written to the client until they are used
 in a method call, such as appendChild(), and then are written in one large message, they are very
 fast.  a side effect of this means that attempting to set attributes, properties, or to call
@@ -212,7 +212,7 @@ such as loading thousands of lines into a list, as with all Perl, TIMTOWTDI:
 
     buffered {                                                  # a touch longer than the first
         $ID{list}->removeItemAt(0) for 1..shift;                # but easily as clean, and much faster
-        $ID{list}->appendItem($_, $_) for @items;               # keep in mind that dependant values
+        $ID{list}->appendItem($_, $_) for @items;               # keep in mind that dependent values
     } $ID{list}->getRowCount;                                   # such as this line need to be passed
                                                                 # in or escaped within a now block
 
@@ -228,15 +228,15 @@ such as loading thousands of lines into a list, as with all Perl, TIMTOWTDI:
     now { CODE };
 
 buffered accepts a code block that defers proxying all commands to the gui until the block ends.
-it also accepts a list incase you need to pass in any non-defered attributes, as in the last section.
+it also accepts a list in case you need to pass in any non-defered attributes, as in the last section.
 
 cached accepts a code block that performs set calls normally, but only performs a particular get once,
-and then afterwards always returns the same value. javascript function calls behave normally
+and then afterward always returns the same value. javascript function calls behave normally
 
 now is provided as a way to temporarily escape a buffered or cached block without causing a buffer
 flush or a cache reset.  it does nothing outside of a pragmatic block.
 
-buffered retuns the value of the combined javascript call, useful for testing for errors.
+buffered returns the value of the combined javascript call, useful for testing for errors.
 cached and now return the result of their last perl expression.
 
 buffered and cached can be nested in either order.  when inside both, get calls are cached,
@@ -249,7 +249,7 @@ note that all subroutines called from within a pragmatic block retain that pragm
 
 =cut
 
-#Buffer is like Buffered but allows you to fine tune which commands are buffered and which arent.
+#Buffer is like Buffered but allows you to fine tune which commands are buffered and which aren't.
 #the options for it's scalar value are 'set', 'get', or 'call' or any combination separated
 #with spaces such as 'set call'
 
@@ -279,7 +279,7 @@ inside of each widget, the following variables are defined:
     %A  the attributes passed in to the widget
     @C  the children passed into the widget
     %M  a hash containing widget methods, which can be added to
-    $W  the widget itself, incase you need to call any methods during construction
+    $W  the widget itself, in case you need to call any methods during construction
 
     $W->mymethod   is the same as  $M{mymethod}($W)
 
@@ -343,7 +343,7 @@ own lexical id space.
 
 =head3 Widgets As Classes
 
-prevously we have seen that widgets behave like Tag objects, but Widgets can also behave like
+previously we have seen that widgets behave like Tag objects, but Widgets can also behave like
 classes, using the extends function.
 
     *SuperClass = widget{
@@ -358,7 +358,7 @@ classes, using the extends function.
 
 any SubClass objects now have both the 'submethod' and 'supermethod' methods, and SubClass
 creates the same gui elements as SuperClass.  It does this because extends returns the results
-from the &SuperClass call.  This also means that you are free to rearange, add, or dismiss objects
+from the &SuperClass call.  This also means that you are free to rearrange, add, or dismiss objects
 from the SuperClass as you see fit.  Named ID's from the superclass are also in the subclass.
 
     *ReverseClass = widget{
@@ -388,13 +388,13 @@ MyWidget can now be called like any native tag object
 
 =head3 inline methods
 
-any key value pair in a tag's argument list with a coderef value and a key that doesnt match /^on/ is entered into that
+any key value pair in a tag's argument list with a coderef value and a key that doesn't match /^on/ is entered into that
 tag's method table, as if it were a widget.
 
 
 =head2 new javascript functions
 
-while XUL and the dom in general have a fairly decent interface, there is of course a bit lacking,
+while XUL and the DOM in general have a fairly decent interface, there is of course a bit lacking,
 otherwise jQuery and the like would not exist.  While you can of course use any of those javascript extensions
 from perl simply by including them in a script tag as you would normally, i felt that several key methods
 should be added by default, some of which are simply plural versions of existing functions, which i find
